@@ -50,7 +50,8 @@ def get_http_host() -> str:
 def get_http_host_ip() -> str:
 
     global http_host
-    return urlparse(http_host).scheme
+    # return urlparse(http_host).scheme
+    return http_host.split(":")[0]
 
 def upload_config():
     pass
